package main

import (
	"fmt"
	"io/ioutil"
	"net/http"
	"os"
	"strings"
)

const beginningToken = "\"articleBody\""
const endToken = ",\"keywords\":"

func main() {
	if len(os.Args) != 2 {
		fmt.Fprintf(os.Stderr, "USAGE: %s URL\n", os.Args[0])
		os.Exit(-1)
	}

	url := os.Args[1]

	if url == "-h" || url == "--help" {
		fmt.Fprintf(os.Stderr, "USAGE: %s URL\n", os.Args[0])
		os.Exit(2)
	}

	resp, err := http.Get(url)
	if err != nil {
		panic(err)
	}
	defer resp.Body.Close()

	body, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		panic(err)
	}

	theLine := ""
	for _, line := range strings.Split(string(body), "\n") {
		if strings.Contains(line, beginningToken) {
			theLine = line
		}
	}

	if theLine == "" {
		panic("articleBody not found")
	}

	index := strings.Index(theLine, beginningToken)
	endIndex := strings.Index(theLine, endToken)

	if index == -1 || endIndex == -1 {
		panic("cannot determine limits")
	}

	if index > endIndex {
		panic("end found before beginning")
	}

	theLine = theLine[index+len(beginningToken)+2 : endIndex-1]

	fmt.Println(theLine)
}
